package com.install4j.api.beaninfo;

/**
 * Enumeration class for all possible failure strategies of actions.
 * @see ActionBeanInfo#setDefaultFailureStrategy(FailureStrategy)
 */
public enum FailureStrategy {

    /**
     * Continue after a failure.
     */
    CONTINUE(com.install4j.runtime.beans.actions.FailureStrategy.CONTINUE.getIntValue()),

    /**
     * Quit after a failure.
     */
    QUIT(com.install4j.runtime.beans.actions.FailureStrategy.QUIT.getIntValue()),

    /**
     * Ask the user whether to continue or to quit.
     */
    ASK_USER(com.install4j.runtime.beans.actions.FailureStrategy.ASK_USER.getIntValue()),

    /**
     * Ask the user whether to continue, to retry or to quit.
     */
    ASK_USER_RETRY(com.install4j.runtime.beans.actions.FailureStrategy.ASK_USER_RETRY.getIntValue()),

    /**
     * No further actions will be executed and the previous screen will be displayed again.
     * If the action is contained the startup node, the first screen will be displayed.
     */
    RETURN_TO_SCREEN(com.install4j.runtime.beans.actions.FailureStrategy.RETURN_TO_SCREEN.getIntValue());

    private int id;

    FailureStrategy(int id) {
        this.id = id;
    }

    /**
     * Convert to an int value.
     * @return the int value
     */
    public int getId() {
        return id;
    }
}
